def _define_locations():
    define_location("Uni", network_in_sight="eduroam")
    define_location("Home", network_in_sight="ASPB") #coordinates=(51.705281, 8.77258, 500))

def _define_gestalts():
    define_gestalt("Default",
            availability="available",
            profile="general",
    )
    define_gestalt("Sleeping",
            availability="offline",
            profile="silent",
    )
    suggest("Default")

def alex_rules():
    if time.between("8:00", "17:45") and location.near("Uni"):
        vote(profile, "silent")
    if location.near("Uni"):
        vote(wifi, "eduroam")
    #if moving:
    #    vote(secure, on)
    #else:
    #    vote(secure, off)
    if not_moving_for_5min:
         vote(availability, "away", 2)
         vote(availability_message, "Mobile phone lying still somewhere.")
    if time.between("1:00", "8:00") and location.near("Home"):
        require("Sleeping")
    if on_stand:
        force(lock, off)
    if not moving and not face_up:
        vote(profile, "silent")

